# PaxosDB
Highly Available store for config and state
 * Compare and Swap updates
 * Replicated and Strongly Consistent
 * Paxos for leaderless, synchronous and consistent replication
 * SQLite for persistence.
 * HTTPS and API Key based auth.
